known_chains = {
    "STEEM": {
        "chain_id": "0" * int(256 / 4),
        "prefix": "STM",
        "steem_symbol": "STEEM",
        "sbd_symbol": "SBD",
        "vests_symbol": "VESTS",
    },
    "TEST": {
        "chain_id":
            "9afbce9f2416520733bacb370315d32b6b2c43d6097576df1c1222859d91eecc",
        "prefix":
            "TST",
        "steem_symbol":
            "TESTS",
        "sbd_symbol":
            "TBD",
        "vests_symbol":
            "VESTS",
    },
}
